@@ -1,3 +1,12 @@
+pGumbel <- function (q, loc = 0, scale = 1, lower.tail = TRUE) 
+{
+    q <- (q - loc)/scale
+    p <- exp(-exp(q))
+    if (lower.tail) 
+        1 - p
+    else p
+}
+
 pgumbel <- function(q, loc = 0, scale = 1, lower.tail = TRUE)
 {
     q <- (q - loc)/scale
